@@ -355,9 +355,9 @@ data(etitanic)
 a <- earth(survived ~ pclass+sex+age, data=etitanic, degree=2)
 print(summary(a))
 plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age")
-plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all1=T", all1=T)
-plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all2=T", all2=T)
-plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all1=T, all2=T", all1=T, all2=T)
+plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all1=T, grid=T", all1=T, grid=T)
+plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all2=T, grid=\"green\"", all2=T, grid="green")
+plotmo(a, trace=Trace, caption="plotmo with facs: pclass+sex+age, all1=T, all2=T, grid=2:3", all1=T, all2=T, grid=2:3)
 plotmo(a, trace=Trace, clip=FALSE, degree2=FALSE, caption="plotmo (no degree2) with facs: pclass+sex+age")
 plotmo(a, trace=Trace, clip=FALSE, grid.levels=list(pclass="2n", sex="ma"),
        caption="plotmo with grid.levels: pclass+sex+age")
