@@ -4,11 +4,12 @@
 library(plotmo)
 library(earth)
 library(rpart)
+source("fast.postscript.R")
 data(ozone1)
 data(etitanic)
 options(warn=1) # print warnings as they occur
 if(!interactive())
-    postscript(paper="letter")
+    fast.postscript(paper="letter")
 
 cat("==test plotmo with factors==\n")
 test.fac.with.rpart <- function(ngrid2=20)
